@@ -252,17 +252,18 @@ class VelociraptorLine(object):
             mask = isnan(x)
             masked_x = masked_x[~mask]
 
+        if (self.lower is not None) and (self.upper is not None):
+            assert self.upper > self.lower
+
         if self.lower is not None:
             self.lower.convert_to_units(y.units)
-            mask = masked_y > self.lower
-            masked_x = masked_x[mask]
-            masked_y = masked_y[mask]
+            mask = masked_y < self.lower
+            masked_y[mask] = self.lower
 
         if self.upper is not None:
             self.upper.convert_to_units(y.units)
-            mask = masked_y < self.upper
-            masked_x = masked_x[mask]
-            masked_y = masked_y[mask]
+            mask = masked_y > self.upper
+            masked_y[mask] = self.upper
 
         if self.median:
             self.output = lines.binned_median_line(
