@@ -369,24 +369,24 @@ def VR_to_SOAP(particle_property_name: str) -> str:
         "angular_momentum.lx_200m_star": ("so.200_mean.angularmomentumstars", 0),
         "angular_momentum.lx_bn98_gas": ("so.bn98.angularmomentumgas", 0),
         "angular_momentum.lx_bn98_star": ("so.bn98.angularmomentumstars", 0),
-        "angular_momentum.lx_gas": ("boundsubhaloproperties.angularmomentumgas", 0),
-        "angular_momentum.lx_star": ("boundsubhaloproperties.angularmomentumstars", 0),
+        "angular_momentum.lx_gas": ("boundsubhalo.angularmomentumgas", 0),
+        "angular_momentum.lx_star": ("boundsubhalo.angularmomentumstars", 0),
         "angular_momentum.ly_200c_gas": ("so.200_crit.angularmomentumgas", 1),
         "angular_momentum.ly_200c_star": ("so.200_crit.angularmomentumstars", 1),
         "angular_momentum.ly_200m_gas": ("so.200_mean.angularmomentumgas", 1),
         "angular_momentum.ly_200m_star": ("so.200_mean.angularmomentumstars", 1),
         "angular_momentum.ly_bn98_gas": ("so.bn98.angularmomentumgas", 1),
         "angular_momentum.ly_bn98_star": ("so.bn98.angularmomentumstars", 1),
-        "angular_momentum.ly_gas": ("boundsubhaloproperties.angularmomentumgas", 1),
-        "angular_momentum.ly_star": ("boundsubhaloproperties.angularmomentumstars", 1),
+        "angular_momentum.ly_gas": ("boundsubhalo.angularmomentumgas", 1),
+        "angular_momentum.ly_star": ("boundsubhalo.angularmomentumstars", 1),
         "angular_momentum.lz_200c_gas": ("so.200_crit.angularmomentumgas", 2),
         "angular_momentum.lz_200c_star": ("so.200_crit.angularmomentumstars", 2),
         "angular_momentum.lz_200m_gas": ("so.200_mean.angularmomentumgas", 2),
         "angular_momentum.lz_200m_star": ("so.200_mean.angularmomentumstars", 2),
         "angular_momentum.lz_bn98_gas": ("so.bn98.angularmomentumgas", 2),
         "angular_momentum.lz_bn98_star": ("so.bn98.angularmomentumstars", 2),
-        "angular_momentum.lz_gas": ("boundsubhaloproperties.angularmomentumgas", 2),
-        "angular_momentum.lz_star": ("boundsubhaloproperties.angularmomentumstars", 2),
+        "angular_momentum.lz_gas": ("boundsubhalo.angularmomentumgas", 2),
+        "angular_momentum.lz_star": ("boundsubhalo.angularmomentumstars", 2),
         "masses.mass_200crit": ("so.200_crit.totalmass", -1),
         "masses.mass_200crit_gas": ("so.200_crit.gasmass", -1),
         "masses.mass_200crit_star": ("so.200_crit.stellarmass", -1),
@@ -396,11 +396,11 @@ def VR_to_SOAP(particle_property_name: str) -> str:
         "masses.mass_bn98": ("so.bn98.totalmass", -1),
         "masses.mass_bn98_gas": ("so.bn98.gasmass", -1),
         "masses.mass_bn98_star": ("so.bn98.stellarmass", -1),
-        "masses.mass_fof": ("fofsubhaloproperties.totalmass", -1),
-        "masses.mass_bh": ("boundsubhaloproperties.blackholesdynamicalmass", -1),
-        "masses.mass_gas": ("boundsubhaloproperties.gasmass", -1),
-        "masses.mass_star": ("boundsubhaloproperties.stellarmass", -1),
-        "masses.mass_tot": ("boundsubhaloproperties.totalmass", -1),
+        "masses.mass_fof": ("boundsubhalo.totalmass", -1),
+        "masses.mass_bh": ("boundsubhalo.blackholesdynamicalmass", -1),
+        "masses.mass_gas": ("boundsubhalo.gasmass", -1),
+        "masses.mass_star": ("boundsubhalo.stellarmass", -1),
+        "masses.mass_tot": ("boundsubhalo.totalmass", -1),
         "projected_apertures.projected_1_sfr_gas_100_kpc": (
             "projectedaperture.100kpc.projx.starformationrate",
             -1,
@@ -692,10 +692,10 @@ def VR_to_SOAP(particle_property_name: str) -> str:
         "radii.r_200crit": ("so.200_crit.soradius", -1),
         "radii.r_200mean": ("so.200_mean.soradius", -1),
         "radii.r_bn98": ("so.bn98.soradius", -1),
-        "radii.r_halfmass": ("boundsubhaloproperties.halfmassradiustotal", -1),
-        "radii.r_halfmass_gas": ("boundsubhaloproperties.halfmassradiusgas", -1),
-        "radii.r_halfmass_star": ("boundsubhaloproperties.halfmassradiusstars", -1),
-        "star_formation_rate.sfr_gas": ("boundsubhaloproperties.starformationrate", -1),
+        "radii.r_halfmass": ("boundsubhalo.halfmassradiustotal", -1),
+        "radii.r_halfmass_gas": ("boundsubhalo.halfmassradiusgas", -1),
+        "radii.r_halfmass_star": ("boundsubhalo.halfmassradiusstars", -1),
+        "star_formation_rate.sfr_gas": ("boundsubhalo.starformationrate", -1),
         "spherical_overdensities.lx_gas_1000_rhocrit": (
             "so.1000_crit.angularmomentumgas",
             0,
@@ -851,114 +851,50 @@ def VR_to_SOAP(particle_property_name: str) -> str:
         "spherical_overdensities.r_200_rhocrit": ("so.200_crit.soradius", -1),
         "spherical_overdensities.r_2500_rhocrit": ("so.2500_crit.soradius", -1),
         "spherical_overdensities.r_500_rhocrit": ("so.500_crit.soradius", -1),
-        "structure_type.structuretype": ("vr.structuretype", -1),
-        "black_hole_masses.max": (
-            "boundsubhaloproperties.mostmassiveblackholemass",
-            -1,
-        ),
-        "temperature.t_gas": ("boundsubhaloproperties.gastemperature", -1),
+        "structure_type.structuretype": ("inputhalos.iscentral", -1),
+        "black_hole_masses.max": ("boundsubhalo.mostmassiveblackholemass", -1),
+        "temperature.t_gas": ("boundsubhalo.gastemperature", -1),
         "temperature.t_gas_hight_incl": (
-            "boundsubhaloproperties.gastemperaturewithoutcoolgas",
-            -1,
-        ),
-        "velocities.vxc": ("boundsubhaloproperties.centreofmassvelocity", 0),
-        "velocities.vyc": ("boundsubhaloproperties.centreofmassvelocity", 1),
-        "velocities.vzc": ("boundsubhaloproperties.centreofmassvelocity", 2),
-        "velocities.vmax": ("boundsubhaloproperties.maximumcircularvelocity", -1),
-        "positions.xc": ("boundsubhaloproperties.centreofmass", 0),
-        "positions.xcmbp": ("vr.centreofpotential", 0),
-        "positions.xcminpot": ("vr.centreofpotential", 0),
-        "positions.yc": ("boundsubhaloproperties.centreofmass", 1),
-        "positions.ycmbp": ("vr.centreofpotential", 1),
-        "positions.ycminpot": ("vr.centreofpotential", 1),
-        "positions.zc": ("boundsubhaloproperties.centreofmass", 2),
-        "positions.zcmbp": ("vr.centreofpotential", 2),
-        "positions.zcminpot": ("vr.centreofpotential", 2),
-        "metallicity.zmet_gas": ("boundsubhaloproperties.gasmassfractioninmetals", -1),
-        "metallicity.zmet_star": (
-            "boundsubhaloproperties.stellarmassfractioninmetals",
-            -1,
-        ),
-        "ids.hosthaloid": ("vr.hosthaloid", -1),
-        "number.bh": ("boundsubhaloproperties.numberofblackholeparticles", -1),
-        "number.gas": ("boundsubhaloproperties.numberofgasparticles", -1),
-        "number.star": ("boundsubhaloproperties.numberofstarparticles", -1),
-        "veldisp.veldisp_xx_gas": (
-            "boundsubhaloproperties.gasvelocitydispersionmatrix",
-            0,
-        ),
-        "veldisp.veldisp_xx_star": (
-            "boundsubhaloproperties.stellarvelocitydispersionmatrix",
-            0,
-        ),
-        "veldisp.veldisp_xy_gas": (
-            "boundsubhaloproperties.gasvelocitydispersionmatrix",
-            3,
-        ),
-        "veldisp.veldisp_xy_star": (
-            "boundsubhaloproperties.stellarvelocitydispersionmatrix",
-            3,
-        ),
-        "veldisp.veldisp_xz_gas": (
-            "boundsubhaloproperties.gasvelocitydispersionmatrix",
-            4,
-        ),
-        "veldisp.veldisp_xz_star": (
-            "boundsubhaloproperties.stellarvelocitydispersionmatrix",
-            4,
-        ),
-        "veldisp.veldisp_yx_gas": (
-            "boundsubhaloproperties.gasvelocitydispersionmatrix",
-            3,
-        ),
-        "veldisp.veldisp_yx_star": (
-            "boundsubhaloproperties.stellarvelocitydispersionmatrix",
-            3,
-        ),
-        "veldisp.veldisp_yy_gas": (
-            "boundsubhaloproperties.gasvelocitydispersionmatrix",
-            1,
-        ),
-        "veldisp.veldisp_yy_star": (
-            "boundsubhaloproperties.stellarvelocitydispersionmatrix",
-            1,
-        ),
-        "veldisp.veldisp_yz_gas": (
-            "boundsubhaloproperties.gasvelocitydispersionmatrix",
-            5,
-        ),
-        "veldisp.veldisp_yz_star": (
-            "boundsubhaloproperties.stellarvelocitydispersionmatrix",
-            5,
-        ),
-        "veldisp.veldisp_zx_gas": (
-            "boundsubhaloproperties.gasvelocitydispersionmatrix",
-            4,
-        ),
-        "veldisp.veldisp_zx_star": (
-            "boundsubhaloproperties.stellarvelocitydispersionmatrix",
-            4,
-        ),
-        "veldisp.veldisp_zy_gas": (
-            "boundsubhaloproperties.gasvelocitydispersionmatrix",
-            5,
-        ),
-        "veldisp.veldisp_zy_star": (
-            "boundsubhaloproperties.stellarvelocitydispersionmatrix",
-            5,
-        ),
-        "veldisp.veldisp_zz_gas": (
-            "boundsubhaloproperties.gasvelocitydispersionmatrix",
-            2,
-        ),
-        "veldisp.veldisp_zz_star": (
-            "boundsubhaloproperties.stellarvelocitydispersionmatrix",
-            2,
-        ),
-        "stellar_age.tage_star": (
-            "boundsubhaloproperties.massweightedmeanstellarage",
+            "boundsubhalo.gastemperaturewithoutcoolgas",
             -1,
         ),
+        "velocities.vxc": ("boundsubhalo.centreofmassvelocity", 0),
+        "velocities.vyc": ("boundsubhalo.centreofmassvelocity", 1),
+        "velocities.vzc": ("boundsubhalo.centreofmassvelocity", 2),
+        "velocities.vmax": ("boundsubhalo.maximumcircularvelocity", -1),
+        "positions.xc": ("boundsubhalo.centreofmass", 0),
+        "positions.xcmbp": ("inputhalos.halocentre", 0),
+        "positions.xcminpot": ("inputhalos.halocentre", 0),
+        "positions.yc": ("boundsubhalo.centreofmass", 1),
+        "positions.ycmbp": ("inputhalos.halocentre", 1),
+        "positions.ycminpot": ("inputhalos.halocentre", 1),
+        "positions.zc": ("boundsubhalo.centreofmass", 2),
+        "positions.zcmbp": ("inputhalos.halocentre", 2),
+        "positions.zcminpot": ("inputhalos.halocentre", 2),
+        "metallicity.zmet_gas": ("boundsubhalo.gasmassfractioninmetals", -1),
+        "metallicity.zmet_star": ("boundsubhalo.stellarmassfractioninmetals", -1),
+        "number.bh": ("boundsubhalo.numberofblackholeparticles", -1),
+        "number.gas": ("boundsubhalo.numberofgasparticles", -1),
+        "number.star": ("boundsubhalo.numberofstarparticles", -1),
+        "veldisp.veldisp_xx_gas": ("boundsubhalo.gasvelocitydispersionmatrix", 0),
+        "veldisp.veldisp_xx_star": ("boundsubhalo.stellarvelocitydispersionmatrix", 0),
+        "veldisp.veldisp_xy_gas": ("boundsubhalo.gasvelocitydispersionmatrix", 3),
+        "veldisp.veldisp_xy_star": ("boundsubhalo.stellarvelocitydispersionmatrix", 3),
+        "veldisp.veldisp_xz_gas": ("boundsubhalo.gasvelocitydispersionmatrix", 4),
+        "veldisp.veldisp_xz_star": ("boundsubhalo.stellarvelocitydispersionmatrix", 4),
+        "veldisp.veldisp_yx_gas": ("boundsubhalo.gasvelocitydispersionmatrix", 3),
+        "veldisp.veldisp_yx_star": ("boundsubhalo.stellarvelocitydispersionmatrix", 3),
+        "veldisp.veldisp_yy_gas": ("boundsubhalo.gasvelocitydispersionmatrix", 1),
+        "veldisp.veldisp_yy_star": ("boundsubhalo.stellarvelocitydispersionmatrix", 1),
+        "veldisp.veldisp_yz_gas": ("boundsubhalo.gasvelocitydispersionmatrix", 5),
+        "veldisp.veldisp_yz_star": ("boundsubhalo.stellarvelocitydispersionmatrix", 5),
+        "veldisp.veldisp_zx_gas": ("boundsubhalo.gasvelocitydispersionmatrix", 4),
+        "veldisp.veldisp_zx_star": ("boundsubhalo.stellarvelocitydispersionmatrix", 4),
+        "veldisp.veldisp_zy_gas": ("boundsubhalo.gasvelocitydispersionmatrix", 5),
+        "veldisp.veldisp_zy_star": ("boundsubhalo.stellarvelocitydispersionmatrix", 5),
+        "veldisp.veldisp_zz_gas": ("boundsubhalo.gasvelocitydispersionmatrix", 2),
+        "veldisp.veldisp_zz_star": ("boundsubhalo.stellarvelocitydispersionmatrix", 2),
+        "stellar_age.tage_star": ("boundsubhalo.massweightedmeanstellarage", -1),
         "snia_rates.snia_rates_30_kpc": ("exclusivesphere.30kpc.totalsniarate", -1),
         "snia_rates.snia_rates_50_kpc": ("exclusivesphere.50kpc.totalsniarate", -1),
         "snia_rates.snia_rates_100_kpc": ("exclusivesphere.100kpc.totalsniarate", -1),
@@ -1222,20 +1158,32 @@ def VR_to_SOAP(particle_property_name: str) -> str:
             "exclusivesphere.100kpc.gasmassincolddensegas",
             -1,
         ),
-        "stellar_birth_densities.logaverage": (
-            "fofsubhaloproperties.logarithmicallyaveragedstellarbirthdensity",
+        "stellar_birth_densities.median": (
+            "boundsubhalo.medianstellarbirthdensity",
             -1,
         ),
-        "stellar_birth_densities.min": (
-            "fofsubhaloproperties.minimumstellarbirthdensity",
+        "stellar_birth_densities.min": ("boundsubhalo.minimumstellarbirthdensity", -1),
+        "stellar_birth_densities.max": ("boundsubhalo.maximumstellarbirthdensity", -1),
+        "stellar_birth_pressures.median": (
+            "boundsubhalo.medianstellarbirthpressure",
             -1,
         ),
-        "stellar_birth_densities.max": (
-            "fofsubhaloproperties.maximumstellarbirthdensity",
+        "stellar_birth_pressures.min": ("boundsubhalo.minimumstellarbirthpressure", -1),
+        "stellar_birth_pressures.max": ("boundsubhalo.maximumstellarbirthpressure", -1),
+        "stellar_birth_temperatures.median": (
+            "boundsubhalo.medianstellarbirthtemperature",
+            -1,
+        ),
+        "stellar_birth_temperatures.min": (
+            "boundsubhalo.minimumstellarbirthtemperature",
+            -1,
+        ),
+        "stellar_birth_temperatures.max": (
+            "boundsubhalo.maximumstellarbirthtemperature",
             -1,
         ),
         "snii_thermal_feedback_densities.max": (
-            "fofsubhaloproperties.lastsupernovaeventmaximumgasdensity",
+            "boundsubhalo.lastsupernovaeventmaximumgasdensity",
             -1,
         ),
         "lin_element_ratios_times_masses.lin_O_over_H_total_times_gas_mass_30_kpc": (
@@ -1262,6 +1210,102 @@ def VR_to_SOAP(particle_property_name: str) -> str:
             "exclusivesphere.100kpc.linearmassweighteddiffuseoxygenoverhydrogenofgas",
             -1,
         ),
+        "lin_element_ratios_times_masses.lin_N_over_O_total_times_gas_mass_30_kpc": (
+            "exclusivesphere.30kpc.linearmassweightednitrogenoveroxygenofgas",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_N_over_O_total_times_gas_mass_50_kpc": (
+            "exclusivesphere.50kpc.linearmassweightednitrogenoveroxygenofgas",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_N_over_O_total_times_gas_mass_100_kpc": (
+            "exclusivesphere.100kpc.linearmassweightednitrogenoveroxygenofgas",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_N_over_O_times_gas_mass_30_kpc": (
+            "exclusivesphere.30kpc.linearmassweighteddiffusenitrogenoveroxygenofgas",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_N_over_O_times_gas_mass_50_kpc": (
+            "exclusivesphere.50kpc.linearmassweighteddiffusenitrogenoveroxygenofgas",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_N_over_O_times_gas_mass_100_kpc": (
+            "exclusivesphere.100kpc.linearmassweighteddiffusenitrogenoveroxygenofgas",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_N_over_O_times_gas_mass_lowfloor_30_kpc": (
+            "exclusivesphere.30kpc.logarithmicmassweighteddiffusenitrogenoveroxygenofgaslowlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_N_over_O_times_gas_mass_lowfloor_50_kpc": (
+            "exclusivesphere.50kpc.logarithmicmassweighteddiffusenitrogenoveroxygenofgaslowlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_N_over_O_times_gas_mass_lowfloor_100_kpc": (
+            "exclusivesphere.100kpc.logarithmicmassweighteddiffusenitrogenoveroxygenofgaslowlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_N_over_O_times_gas_mass_highfloor_30_kpc": (
+            "exclusivesphere.30kpc.logarithmicmassweighteddiffusenitrogenoveroxygenofgashighlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_N_over_O_times_gas_mass_highfloor_50_kpc": (
+            "exclusivesphere.50kpc.logarithmicmassweighteddiffusenitrogenoveroxygenofgashighlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_N_over_O_times_gas_mass_highfloor_100_kpc": (
+            "exclusivesphere.100kpc.logarithmicmassweighteddiffusenitrogenoveroxygenofgashighlimit",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_C_over_O_total_times_gas_mass_30_kpc": (
+            "exclusivesphere.30kpc.linearmassweightedcarbonoveroxygenofgas",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_C_over_O_total_times_gas_mass_50_kpc": (
+            "exclusivesphere.50kpc.linearmassweightedcarbonoveroxygenofgas",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_C_over_O_total_times_gas_mass_100_kpc": (
+            "exclusivesphere.100kpc.linearmassweightedcarbonoveroxygenofgas",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_C_over_O_times_gas_mass_30_kpc": (
+            "exclusivesphere.30kpc.linearmassweighteddiffusecarbonoveroxygenofgas",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_C_over_O_times_gas_mass_50_kpc": (
+            "exclusivesphere.50kpc.linearmassweighteddiffusecarbonoveroxygenofgas",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_C_over_O_times_gas_mass_100_kpc": (
+            "exclusivesphere.100kpc.linearmassweighteddiffusecarbonoveroxygenofgas",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_C_over_O_times_gas_mass_lowfloor_30_kpc": (
+            "exclusivesphere.30kpc.logarithmicmassweighteddiffusecarbonoveroxygenofgaslowlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_C_over_O_times_gas_mass_lowfloor_50_kpc": (
+            "exclusivesphere.50kpc.logarithmicmassweighteddiffusecarbonoveroxygenofgaslowlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_C_over_O_times_gas_mass_lowfloor_100_kpc": (
+            "exclusivesphere.100kpc.logarithmicmassweighteddiffusecarbonoveroxygenofgaslowlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_C_over_O_times_gas_mass_highfloor_30_kpc": (
+            "exclusivesphere.30kpc.logarithmicmassweighteddiffusecarbonoveroxygenofgashighlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_C_over_O_times_gas_mass_highfloor_50_kpc": (
+            "exclusivesphere.50kpc.logarithmicmassweighteddiffusecarbonoveroxygenofgashighlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_C_over_O_times_gas_mass_highfloor_100_kpc": (
+            "exclusivesphere.100kpc.logarithmicmassweighteddiffusecarbonoveroxygenofgashighlimit",
+            -1,
+        ),
         "log_element_ratios_times_masses.log_O_over_H_times_gas_mass_lowfloor_30_kpc": (
             "exclusivesphere.30kpc.logarithmicmassweighteddiffuseoxygenoverhydrogenofgaslowlimit",
             -1,
@@ -1370,6 +1414,42 @@ def VR_to_SOAP(particle_property_name: str) -> str:
             "exclusivesphere.100kpc.logarithmicmassweightedironoverhydrogenofstarshighlimit",
             -1,
         ),
+        "lin_element_ratios_times_masses.lin_Mg_over_H_times_star_mass_30_kpc": (
+            "exclusivesphere.30kpc.linearmassweightedmagnesiumoverhydrogenofstars",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_Mg_over_H_times_star_mass_50_kpc": (
+            "exclusivesphere.50kpc.linearmassweightedmagnesiumoverhydrogenofstars",
+            -1,
+        ),
+        "lin_element_ratios_times_masses.lin_Mg_over_H_times_star_mass_100_kpc": (
+            "exclusivesphere.100kpc.linearmassweightedmagnesiumoverhydrogenofstars",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_Mg_over_H_times_star_mass_lowfloor_30_kpc": (
+            "exclusivesphere.30kpc.logarithmicmassweightedmagnesiumoverhydrogenofstarslowlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_Mg_over_H_times_star_mass_lowfloor_50_kpc": (
+            "exclusivesphere.50kpc.logarithmicmassweightedmagnesiumoverhydrogenofstarslowlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_Mg_over_H_times_star_mass_lowfloor_100_kpc": (
+            "exclusivesphere.100kpc.logarithmicmassweightedmagnesiumoverhydrogenofstarslowlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_Mg_over_H_times_star_mass_highfloor_30_kpc": (
+            "exclusivesphere.30kpc.logarithmicmassweightedmagnesiumoverhydrogenofstarshighlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_Mg_over_H_times_star_mass_highfloor_50_kpc": (
+            "exclusivesphere.50kpc.logarithmicmassweightedmagnesiumoverhydrogenofstarshighlimit",
+            -1,
+        ),
+        "log_element_ratios_times_masses.log_Mg_over_H_times_star_mass_highfloor_100_kpc": (
+            "exclusivesphere.100kpc.logarithmicmassweightedmagnesiumoverhydrogenofstarshighlimit",
+            -1,
+        ),
         "cold_dense_gas_properties.cold_dense_diffuse_metal_mass_30_kpc": (
             "exclusivesphere.30kpc.gasmassincolddensediffusemetals",
             -1,
@@ -1406,6 +1486,7 @@ def VR_to_SOAP(particle_property_name: str) -> str:
             "exclusivesphere.100kpc.linearmassweightedironfromsniaoverhydrogenofstars",
             -1,
         ),
+        "searchradius.search_radius": ("boundsubhalo.encloseradius", -1),
     }
 
     try:
